@@ -180,6 +180,9 @@ QString MainWindow::buildOptionList()
     if (ui->cb_force_makefs->isChecked()) {
         options += "--force=makefs ";
     }
+    if (ui->cb_force_nofuse->isChecked()) {
+        options += "--force=nofuse ";
+    }
     if (ui->rb_dd->isChecked()) {
 
     }
@@ -220,7 +223,7 @@ QStringList MainWindow::removeUnsuitable(const QStringList &devices)
 {
     QStringList list;
     QString name;
-    foreach (const QString line, devices) {
+    for (const QString &line : devices) {
         name = line.split(" ").at(0);
         if (system(cli_utils.toUtf8() + "is_usb_or_removable " + name.toUtf8()) == 0) {
             if (cmd->getOutput(cli_utils + "get_drive $(get_live_dev) ") != name) {
